@@ -1,10 +1,13 @@
 package Task::Cabinet;
 
+# ABSTRACT: Install all the CPAN modules needed by Cabinet
+
 use v5.10.1;
 use warnings;
 use strict;
 
-our $VERSION = '0.07';
+our $VERSION = '0.09'; # VERSION
+our $AUTHORITY = 'cpan:CHIM'; # AUTHORITY
 
 1; # End of Task::Cabinet
 
@@ -18,26 +21,25 @@ Task::Cabinet - Install all the CPAN modules needed by Cabinet
 
 =head1 VERSION
 
-version 0.07
+version 0.09
 
 =head1 DESCRIPTION
 
 This L<Task> module installs all the dependencies for the stable version of Cabinet.
 
-=head1 AUTHOR
-
-Anton Gerasimov E<lt>chim@cpan.orgE<gt>
-
 =head1 SEE ALSO
 
 L<Task>
 
+=head1 AUTHOR
+
+Anton Gerasimov <chim@cpan.org>
+
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2012 Anton Gerasimov.
+This software is copyright (c) 2012 by Anton Gerasimov.
 
-This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
-
-The full text of the license can be found in the LICENSE file included with this module.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
